@@ -2186,8 +2186,12 @@ void TopDoLatex()
    fprintf(f, "\\def\\topbox#1{\\raisebox{-\\baselineskip}[0in][0in]{#1}}\n");
    fprintf(f, "\\def\\midbox#1{\\raisebox{-0.5\\baselineskip}[0in][0in]{#1}}\n");
    fprintf(f, "\\begin{flushleft}\n");
-   fprintf(f, "\\epsfig{file=%s.ps}\\\\\n",
-		xobjs.pagelist[areastruct.page]->filename);
+
+   filename[strlen(filename) - 4] = '\0';
+   if (strchr(filename, '.') == NULL)
+      sprintf(filename + strlen(filename), ".ps");
+
+   fprintf(f, "\\epsfig{file=%s}\\\\\n", filename);
 
    psscale = getpsscale(xobjs.pagelist[areastruct.page]->outscale,
 		areastruct.page);
