@@ -120,7 +120,7 @@ Boolean render_client(XEvent *eventPtr)
 #endif
       mwin = eventPtr->xclient.data.l[0];
       Wprintf("Background finished.");
-      XDefineCursor(dpy, areastruct.areawin, CROSS);
+      XDefineCursor(dpy, areastruct.areawin, DEFAULTCURSOR);
 
       /* Mark this as the most recently rendered background, so we don't	*/
       /* have to render more than necessary.					*/
@@ -306,7 +306,7 @@ void start_gs()
 #endif
 #endif
 	 Flush(stderr);
-         execlp(GS_EXEC, "gs", "-dNOPAUSE", "-", NULL);
+         execlp(GS_EXEC, "gs", "-dNOPAUSE", "-", (char *)NULL);
 	 gsproc = -1;
 	 fprintf(stderr, "Exec of gs failed\n");
 	 return;
